@@ -2,9 +2,10 @@ package Net::GitHub::V2::NoRepo;
 
 use Any::Moose 'Role';
 
-our $VERSION = '0.24';
+our $VERSION = '0.41';
 our $AUTHORITY = 'cpan:FAYLAND';
 
+use URI;
 use JSON::Any;
 use WWW::Mechanize::GZip;
 use MIME::Base64;
@@ -12,11 +13,13 @@ use HTTP::Request::Common ();
 use Carp qw/croak/;
 
 # repo stuff
-has 'owner' => ( isa => 'Str', is => 'ro', required => 1 );
+# has 'owner' => ( isa => 'Str', is => 'ro', required => 1 );
+has 'owner' => ( isa => 'Str', is => 'ro' );
 
 # login
 has 'login' => (is => 'rw', isa => 'Str', predicate => 'has_login',);
 has 'token' => (is => 'rw', isa => 'Str', predicate => 'has_token',);
+has 'access_token' => ( is => 'rw' , predicate => 'has_access_token' );
 
 # always send Authorization header, useful for private respo
 has 'always_Authorization' => ( is => 'rw', isa => 'Bool', default => 0 );
@@ -59,21 +62,31 @@ has 'json' => (
     isa => 'JSON::Any',
     lazy => 1,
     default => sub {
-        return JSON::Any->new;
+        return JSON::Any->new( utf8 => 1 );
     }
 );
 
 sub get_json_to_obj {
     my ( $self, $pending_url, $key ) = @_;
-    
+
     if ( $self->always_Authorization ) {
         push @_, 'GET';
         return _get_json_to_obj_authed(@_);
     }
 
     $pending_url =~ s!^/!!; # Strip leading '/'
-    my $url  = $self->api_url . $pending_url;
+    my $url  = URI->new($self->api_url . $pending_url);
+    $url->query_form( access_token => $self->access_token ) if $self->access_token;
     my $resp = $self->ua->get($url);
+
+    # Slow down if we're approaching the rate limit
+    # By the way GitHub mistakes days for minutes in their documentation --
+    # the rate limit is per minute, not per day.
+    if ( $self->api_throttle ) {
+        sleep 2 if (($res->header('x-ratelimit-remaining') || 0)
+            < ($res->header('x-ratelimit-limit') || 60) / 2);
+    }
+
     return { error => '404 Not Found' } if $resp->code == 404;
     return { error => $resp->as_string() } unless ( $resp->is_success );
     my $json = $resp->content();
@@ -88,6 +101,8 @@ before get_json_to_obj_authed => sub {
 
     return if $self->has_login and $self->has_token;
 
+
+    # Gitconfig Fallback
     eval { require Config::GitLike::Git; };
     return if $@;
 
@@ -129,10 +144,10 @@ sub get_json_to_obj_authed_DELETE {
 sub _get_json_to_obj_authed {
     my $self = shift;
     my $pending_url = shift;
-    
     my $request_method = pop @_; # defaults to GET or POST if undefined
 
-    croak 'login and token are required' unless ( $self->has_login and $self->has_token );
+    croak 'login and token or access_token are required' unless (
+        $self->has_login and $self->has_token and $self->has_access_token );
 
     $pending_url =~ s!^/!!; # Strip leading '/'
     my $url  = ( $pending_url =~ /^https?\:/ ) ? $pending_url :
@@ -149,10 +164,15 @@ sub _get_json_to_obj_authed {
               $request_method eq 'POST'   ? HTTP::Request::Common::POST( $url, [ @_ ] ) :
                                             HTTP::Request::Common::GET( $url );
 
-    # "schacon/token:6ef8395fecf207165f1a82178ae1b984"
-    my $auth_basic = $self->login . '/token:' . $self->token;
-    $req->header('Authorization', 'Basic ' . encode_base64($auth_basic));
-    
+    # OAuth access_token
+    if( $self->access_token ) {
+        $req->header( 'access_token' => $self->access_token );
+    } else {
+        # "schacon/token:6ef8395fecf207165f1a82178ae1b984"
+        my $auth_basic = $self->login . '/token:' . $self->token;
+        $req->header('Authorization', 'Basic ' . encode_base64($auth_basic));
+    }
+
     my $res = $self->ua->request($req);
 
     # Slow down if we're approaching the rate limit
@@ -184,7 +204,7 @@ sub _get_json_to_obj_authed {
 sub args_to_pass {
     my $self = shift;
     my $ret;
-    foreach my $col ('owner', 'login', 'token', 'always_Authorization') {
+    foreach my $col ('owner', 'login', 'access_token', 'token', 'always_Authorization') {
         $ret->{$col} = $self->$col;
     }
     return $ret;
